@@ -53,9 +53,10 @@ class DetectSequence(Base):
                             },
 
                             # within object, this is a sequence of object detection libraries. In this case,
-                            # I want to first try on my TPU and if it fails, try GPU
-                            'sequence': [{
-                                #First run on TPU
+                            # First try Coral TPU, if it fails try GPU, and finally, if configured, try AWS Rekognition
+                            'sequence': [
+                            {
+                                # Intel Coral TPU
                                 'object_weights':'/var/lib/zmeventnotification/models/coral_edgetpu/ssd_mobilenet_v2_coco_quant_postprocess_edgetpu.tflite',
                                 'object_labels': '/var/lib/zmeventnotification/models/coral_edgetpu/coco_indexed.names',
                                 'object_min_confidence': 0.3,
@@ -72,7 +73,21 @@ class DetectSequence(Base):
                                 # These are optional below. Default is 416. Change if your model is trained for larger sizes
                                 'model_width': 416, 
                                 'model_height': 416
-                            }]
+                            },
+                            {
+                                # AWS Rekognition object detection
+                                # More info: https://medium.com/@michael-ludvig/aws-rekognition-support-for-zoneminder-object-detection-40b71f926a80
+                                'object_framework': 'aws_rekognition'
+                                'object_min_confidence': 0.7,
+                                # AWS region unless configured otherwise, e.g. in ~www-data/.aws/config
+                                'aws_region': 'us-east-1',
+                                # AWS credentials from /etc/zm/secrets.ini
+                                # unless running on EC2 instance with instance IAM role (which is preferable)
+                                'aws_access_key_id': '!AWS_ACCESS_KEY_ID',
+                                'aws_secret_access_key': '!AWS_SECRET_ACCESS_KEY',
+                                # no other parameters are required
+                            }
+                            ]
                         },
 
                         # We repeat the same exercise with 'face' as it is next in model_sequence
@@ -154,7 +169,7 @@ class DetectSequence(Base):
                 if seq == 'object':
                     import pyzm.ml.object as  ObjectDetect
                     self.models[seq] = []
-                    for ndx,obj_seq in enumerate(self.ml_options.get(seq,{}).get('sequence')):
+                    for ndx,obj_seq in enumerate(self.ml_options.get(seq,{}).get('sequence', [])):
                         if obj_seq.get('enabled') == 'no':
                             g.logger.Debug(2, 'Skipping {} as it is disabled'.format(obj_seq.get('name') or 'index:{}'.format(ndx)))
                             continue
@@ -170,7 +185,7 @@ class DetectSequence(Base):
                 elif seq == 'face':
                     import pyzm.ml.face as FaceDetect
                     self.models[seq] = []
-                    for ndx,face_seq in enumerate(self.ml_options.get(seq,{}).get('sequence')):
+                    for ndx,face_seq in enumerate(self.ml_options.get(seq,{}).get('sequence', [])):
                         if face_seq.get('enabled') == 'no':
                             g.logger.Debug(2, 'Skipping {} as it is disabled'.format(face_seq.get('name') or 'index:{}'.format(ndx)))
                             continue
@@ -184,7 +199,7 @@ class DetectSequence(Base):
                 elif seq == 'alpr':
                     import pyzm.ml.alpr as AlprDetect
                     self.models[seq] = []
-                    for alpr_seq in self.ml_options.get(seq,{}).get('sequence'):
+                    for alpr_seq in self.ml_options.get(seq,{}).get('sequence', []):
                         
                         try:
                             alpr_seq['disable_locks'] = self.ml_options.get('general',{}).get('disable_locks', 'no')
@@ -231,7 +246,7 @@ class DetectSequence(Base):
                 'Monitor ID not specified, cannot match past detections')
             return bbox, label, conf
 
-        image_path = self.global_config.get('image_path') or self.ml_options.get('general',{}).get('image_path') 
+        image_path = self.ml_options.get('general',{}).get('image_path') or self.global_config.get('image_path')
         mon_file = '{}/monitor-{}-data.pkl'.format(image_path,mid)
         g.logger.Debug(2,'trying to load ' + mon_file)
         saved_bs=[]
@@ -262,7 +277,7 @@ class DetectSequence(Base):
         # load past detection
         global_use_percent = False
         global_max_diff_area = 0
-        global_mda = self.global_config.get('past_det_max_diff_area')  or self.ml_options.get('general',{}).get('past_det_max_diff_area') 
+        global_mda = self.ml_options.get('general',{}).get('past_det_max_diff_area')  or self.global_config.get('past_det_max_diff_area')
         if global_mda:
             _m = re.match('(\d+)(px|%)?$', global_mda,re.IGNORECASE)
             if _m:
@@ -318,7 +333,7 @@ class DetectSequence(Base):
                 if use_percent and (max_diff_area < 0 or max_diff_area > 100):
                     g.logger.Error(
                         '{} must be in the range 0-100 when using percentages. Setting to 5%, was {}'
-                        .format(label_max_diff_area, self.global_config.get(label_max_diff_area)))
+                        .format(label_max_diff_area,mda))
                     max_diff_area = 5
 
             # iterate list of detections
@@ -363,12 +378,12 @@ class DetectSequence(Base):
 
                     if diff_area <= max_diff_pixels:
                         g.logger.Debug(1,
-                            'past detection {}@{} approximately matches {}@{} removing'
+                            'match_past_detection: past detection {}@{} approximately matches {}@{} removing'
                             .format(saved_ls[saved_idx], saved_b, label[idx], b))
                         foundMatch = True
                         break
                     else:
-                        g.logger.Debug(2,'Diff area of:{} > max_diff_pixels:{} for {}@{}, allowing it'
+                        g.logger.Debug(2,'match_past_detection: Diff area of:{} > max_diff_pixels:{} for {}@{}, allowing it'
                         .format(diff_area, max_diff_pixels,label[idx], b))
             if not foundMatch:
                 new_bbox.append(old_b)
@@ -482,9 +497,9 @@ class DetectSequence(Base):
 
             for p in polygons:
                 poly = Polygon(p['value'])
-                g.logger.Debug(2,"intersection: comparing object:{},{} to polygon:{},{}".format(label[idx],obj,p['name'],poly))
-
+                
                 if obj.intersects(poly):
+                    g.logger.Debug(2,'intersection: object:{},{} intersects polygon:{},{}'.format(label[idx],obj,p['name'],poly))
                     if  p['pattern']:
                         g.logger.Debug(2, '{} polygon/zone has its own pattern of {}, using that'.format(p['name'],p['pattern']))
                         r = re.compile(p['pattern'])
@@ -495,7 +510,7 @@ class DetectSequence(Base):
                         g.logger.Debug (1,'{}'.format(self.ml_overrides))
                         g.logger.Debug (1,'**********************************')
                         '''
-                        if self.ml_overrides.get(seq,{}).get('pattern'):
+                        if self.ml_overrides.get(seq,{}).get('pattern') and False:
                             match_pattern = self.ml_overrides.get(seq,{}).get('pattern')
                             g.logger.Debug(2,'Match pattern overridden to {} in ml_overrides'.format(match_pattern))
                         else:
@@ -522,7 +537,8 @@ class DetectSequence(Base):
                             .format(p['name'], label[idx], b))
                     doesIntersect = True
                     break
-
+                else:
+                    g.logger.Debug(2,'intersection: object:{},{} DOES NOT intersect polygon:{},{}'.format(label[idx],obj,p['name'],poly))
             # out of poly loop
             if not doesIntersect:
                 new_err.append(old_b)
@@ -647,9 +663,9 @@ class DetectSequence(Base):
             found = False
             g.logger.Debug (1, "Sequence of detection types to execute: {}".format(self.model_sequence))
             for seq in self.model_sequence:
-                if seq not in self.ml_overrides.get('model_sequence',seq):
-                    g.logger.Debug (1, 'Skipping {} as it was overridden in ml_overrides'.format(seq))
-                    continue
+                #if seq not in self.ml_overrides.get('model_sequence',seq):
+                #    g.logger.Debug (1, 'Skipping {} as it was overridden in ml_overrides'.format(seq))
+                #    continue
                 g.logger.Debug(1,'============ Frame: {} Running {} detection type in sequence =================='.format(self.media.get_last_read_frame(),seq))
                 pre_existing_labels = self.ml_options.get(seq,{}).get('general',{}).get('pre_existing_labels')
                 if pre_existing_labels:
@@ -682,7 +698,7 @@ class DetectSequence(Base):
                 cnt = 1
                 # For each model, loop across different variations
                 for m in self.models[seq]:
-                    g.logger.Debug(3,'--------- Frame:{} Running variation: #{} -------------'.format(self.media.get_last_read_frame(),cnt))
+                    g.logger.Debug(1,'--------- Frame:{} Running variation: #{} -------------'.format(self.media.get_last_read_frame(),cnt))
                     cnt +=1
                     pre_existing_labels = m.get_options().get('pre_existing_labels')
                     if pre_existing_labels:
@@ -829,4 +845,4 @@ class DetectSequence(Base):
         return matched_data, all_matches
 
 
-        
\ No newline at end of file
+        
